@@ -173,7 +173,7 @@ muse_dar_correct(muse_pixtable *aPixtable, double aLambdaRef)
   cpl_ensure_code(cpl_errorstate_is_equal(prestate), cpl_error_get_code());
 
   cpl_boolean isWFM = muse_pfits_get_mode(aPixtable->header)
-                    <= MUSE_MODE_WFM_AO_N;
+                    < MUSE_MODE_NFM_AO_N;
   if (!isWFM) {
     cpl_msg_warning(__func__, "For NFM instrument mode DAR correction should "
                     "not be needed!");
@@ -870,7 +870,7 @@ muse_dar_check(muse_pixtable *aPixtable, double *aMaxShift,
   double maxdiffx = xmax - xmin,
          maxdiffy = ymax - ymin;
   /* correct from shift in pixels to shift in arcsec */
-  if (muse_pfits_get_mode(aPixtable->header) <= MUSE_MODE_WFM_AO_N) {
+  if (muse_pfits_get_mode(aPixtable->header) < MUSE_MODE_NFM_AO_N) {
     maxdiffx *= kMuseSpaxelSizeX_WFM;
     maxdiffy *= kMuseSpaxelSizeY_WFM;
   } else {
