@@ -262,6 +262,7 @@ muse_test_pixtable_delete_exptable(cpl_table *aExpTable)
     muse_pixtable_origin_get_y
     muse_pixtable_origin_get_ifu
     muse_pixtable_origin_get_slice
+    muse_pixtable_origin_decode_all
     muse_pixtable_create
     muse_pixtable_delete
     muse_pixtable_append_ff
@@ -306,6 +307,18 @@ int main(int argc, char **argv)
   unsigned int y;
   unsigned char ifu;
   unsigned short slice;
+  /* set up a table, which is not exactly a pixel table, with the     *
+   * columns we need to check muse_pixtable_origin_decode_all() below */
+  muse_pixtable *pt1 = cpl_calloc(1, sizeof(muse_pixtable));
+  pt1->table = cpl_table_new(4*4*3*3);
+  cpl_table_new_column(pt1->table, MUSE_PIXTABLE_ORIGIN, CPL_TYPE_INT);
+  cpl_table_new_column(pt1->table, "x", CPL_TYPE_INT);
+  cpl_table_new_column(pt1->table, "y", CPL_TYPE_INT);
+  cpl_table_new_column(pt1->table, "ifu", CPL_TYPE_INT);
+  cpl_table_new_column(pt1->table, "slice", CPL_TYPE_INT);
+  pt1->header = cpl_propertylist_new();
+  cpl_size irow = 0;
+  /* now loop through all possible values and encode origins */
   int ix, iy, ii, is, io;
   for (ix = 0 ; xrange[ix] >= 0; ix++) {
     for (iy = 0 ; yrange[iy] >= 0; iy++) {
@@ -322,6 +335,23 @@ int main(int argc, char **argv)
                             yrange[iy], ifurange[ii], slicerange[is],
                             offrange[io], origin);
             }
+
+            if (io == 0) {
+              cpl_table_set_int(pt1->table, "x", irow, xrange[ix]);
+              cpl_table_set_int(pt1->table, "y", irow, yrange[iy]);
+              cpl_table_set_int(pt1->table, "ifu", irow, ifurange[ii]);
+              cpl_table_set_int(pt1->table, "slice", irow, slicerange[is]);
+              cpl_table_set_int(pt1->table, MUSE_PIXTABLE_ORIGIN, irow++,
+                                origin);
+              /* add the related header keyword */
+              char *kw = cpl_sprintf(MUSE_HDR_PT_IFU_SLICE_OFFSET, 0,
+                                     ifurange[ii], slicerange[is]);
+              if (!cpl_propertylist_has(pt1->header, kw)) {
+                cpl_propertylist_append_int(pt1->header, kw, 10);
+              }
+              cpl_free(kw);
+            }
+
             // XXX this is not so simple to test as it needs a
             //     pixel table with full header keywords set up
             // unsigned int x = muse_pixtable_origin_get_x(origin, pt, irow);
@@ -341,7 +371,64 @@ int main(int argc, char **argv)
       } /* for ii */
     } /* for iy */
   } /* for ix */
-  /* test failure cases */
+#if 0
+  cpl_table_dump(pt1->table, 0, 150, stdout);
+  cpl_propertylist_dump(pt1->header, stdout);
+  fflush(stdout);
+#endif
+
+  /* test muse_pixtable_origin_decode_all() */
+  unsigned short *xout, *yout;
+  unsigned char *ifuout, *sliceout;
+  ps = cpl_errorstate_get();
+  cpl_test(muse_pixtable_origin_decode_all(pt1, &xout, &yout, &ifuout, &sliceout)
+           == CPL_ERROR_NONE);
+  cpl_test(cpl_errorstate_is_equal(ps));
+  cpl_size irow2;
+  for (irow2 = 0; irow2 < irow; irow2++) {
+    /* do not test the x values, since the offsets in the header *
+     * are difficult to set up correctly in this test program    */
+    cpl_test_eq(yout[irow2], cpl_table_get_int(pt1->table, "y", irow2, NULL));
+    cpl_test_eq(ifuout[irow2], cpl_table_get_int(pt1->table, "ifu", irow2, NULL));
+    cpl_test_eq(sliceout[irow2], cpl_table_get_int(pt1->table, "slice", irow2, NULL));
+  } /* for irow2 (all table rows) */
+  cpl_free(xout);
+  cpl_free(yout);
+  cpl_free(ifuout);
+  cpl_free(sliceout);
+  /* should also work without y */
+  ps = cpl_errorstate_get();
+  cpl_test(muse_pixtable_origin_decode_all(pt1, &xout, NULL, &ifuout, &sliceout)
+           == CPL_ERROR_NONE);
+  cpl_test(cpl_errorstate_is_equal(ps));
+  cpl_free(xout);
+  cpl_free(ifuout);
+  cpl_free(sliceout);
+  /* but not without any of the other pointers */
+  ps = cpl_errorstate_get();
+  cpl_test(muse_pixtable_origin_decode_all(NULL, &xout, &yout, &ifuout, &sliceout)
+           == CPL_ERROR_NULL_INPUT);
+  cpl_test(!cpl_errorstate_is_equal(ps));
+  cpl_errorstate_set(ps);
+  cpl_test(muse_pixtable_origin_decode_all(pt1, NULL, &yout, &ifuout, &sliceout)
+           == CPL_ERROR_NULL_INPUT);
+  cpl_test(!cpl_errorstate_is_equal(ps));
+  cpl_errorstate_set(ps);
+  cpl_test(muse_pixtable_origin_decode_all(pt1, &xout, &yout, NULL, &sliceout)
+           == CPL_ERROR_NULL_INPUT);
+  cpl_test(!cpl_errorstate_is_equal(ps));
+  cpl_errorstate_set(ps);
+  cpl_test(muse_pixtable_origin_decode_all(pt1, &xout, &yout, &ifuout, NULL)
+           == CPL_ERROR_NULL_INPUT);
+  cpl_test(!cpl_errorstate_is_equal(ps));
+  cpl_errorstate_set(ps);
+  cpl_table_name_column(pt1->table, MUSE_PIXTABLE_ORIGIN, "originbad");
+  cpl_test(muse_pixtable_origin_decode_all(pt1, &xout, NULL, &ifuout, &sliceout)
+           == CPL_ERROR_BAD_FILE_FORMAT);
+  cpl_errorstate_set(ps);
+  muse_pixtable_delete(pt1);
+
+  /* test other origin-related failure cases */
   ps = cpl_errorstate_get();
   /* bad x */
   origin = muse_pixtable_origin_encode(0, 1, 1, 1, 1);
@@ -1132,7 +1219,6 @@ int main(int argc, char **argv)
   for (i = 0; i <= 1; i++) {
     cpl_table *exptable = muse_test_pixtable_create_exptable(dir,
                                                              i ? ffspec2 : NULL);
-    cpl_size irow;
     for (irow = 0; irow < cpl_table_get_nrow(exptable); irow++) {
       cpl_table *et = cpl_table_extract(exptable, irow, 1);
       if (irow == 0) {
@@ -1370,7 +1456,6 @@ int main(int argc, char **argv)
   cpl_test(cpl_errorstate_is_equal(ps) && rc == CPL_ERROR_NONE);
   muse_imagelist_delete(images);
   ok = CPL_TRUE;
-  cpl_size irow;
   for (irow = 0; irow < nrow; irow++) {
     double ddiff = fabs(cpl_table_get_float(pt->table, MUSE_PIXTABLE_DATA, irow, NULL)
                         - cpl_table_get_float(ptkeep->table, MUSE_PIXTABLE_DATA, irow, NULL)),
