@@ -78,7 +78,7 @@ muse_test_xcombine_pixtable_create_pos(double aValue, double aRA, double aDEC)
   cpl_table_fill_column_window(pt->table, MUSE_PIXTABLE_STAT, 0, 1, 0.5*aValue);
   cpl_table_fill_column_window(pt->table, MUSE_PIXTABLE_ORIGIN, 0, 1, 0);
   muse_pixtable_compute_limits(pt);
-  cpl_propertylist *wcs = muse_wcs_create_default();
+  cpl_propertylist *wcs = muse_wcs_create_default(NULL);
   muse_wcs_project_tan(pt, wcs);
   cpl_propertylist_delete(wcs);
   return pt;
@@ -217,7 +217,7 @@ muse_test_xcombine_pixtable_create_cosmos(int aExp)
   } /* switch */
   pt->table = muse_cpltable_new(muse_pixtable_def, 1);
   muse_pixtable_compute_limits(pt);
-  cpl_propertylist *wcs = muse_wcs_create_default();
+  cpl_propertylist *wcs = muse_wcs_create_default(NULL);
   muse_wcs_project_tan(pt, wcs);
   cpl_propertylist_delete(wcs);
   return pt;
